"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from datetime import datetime
from pydantic import Field, StrictStr, field_validator
from typing import Any, Optional
from typing_extensions import Annotated
from smartytalent_client.models.create_finder_request_body import CreateFinderRequestBody
from smartytalent_client.models.finder_schema import FinderSchema
from smartytalent_client.models.finders_schema import FindersSchema
from smartytalent_client.models.update_finder_request_body import UpdateFinderRequestBody

from smartytalent_client.api_client import ApiClient, RequestSerialized
from smartytalent_client.api_response import ApiResponse
from smartytalent_client.rest import RESTResponseType


class FindersApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def create_finder(
        self,
        create_finder_request_body: Annotated[CreateFinderRequestBody, Field(description="A JSON object containing Finder information")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> FinderSchema:
        """Create Finder

        Creates a new finder search in your account.  ### Finder's Attributes  Here is a table that describes the attributes of the finder object:  | Attribute | Type | Required | Description | |-----------|------|----------|-------------| | `name` | string | Yes | The name of the finder search (1-256 characters) | | `type` | string | Yes | The type of search: talents, candidates, jobs, emails, users, reports | | `query` | object | No | The search query parameters sent to OpenSearch (e.g. `{ \"type\": \"talents\", \"jobId\": \"...\" }`) | | `results` | object | No | The search results (auto-populated after OpenSearch query execution) | | `status` | string | No | The current status: active (default), pending, completed, failed, archived | | `languageCode` | string | No | Language code for the finder (default: `en`) | | `settings` | object | No | Additional configuration settings | | `source` | string | No | Source of the finder creation (nullable) | | `ttl` | string | No | Time-to-live expiration timestamp in ISO 8601 format (nullable) | | `timestamps.created` | string | No | The date and time when the finder was created (ISO 8601 format) | | `timestamps.modified` | string | No | The date and time when the finder was last modified (ISO 8601 format) |  ### Relationships  | Relationship | Type | Description | |-------------|------|-------------| | `jobs` | array | Associated job resources | | `users` | array | Associated user resources | | `talents` | array | Associated talent resources | | `candidates` | array | Associated candidate resources |  ### Behavior  When a `query` is provided, OpenSearch is queried immediately. The `results` field is populated with matching documents and `status` is set to `completed` or `failed`.

        :param create_finder_request_body: A JSON object containing Finder information (required)
        :type create_finder_request_body: CreateFinderRequestBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_finder_serialize(
            create_finder_request_body=create_finder_request_body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FinderSchema",
            '400': "ErrorSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def create_finder_with_http_info(
        self,
        create_finder_request_body: Annotated[CreateFinderRequestBody, Field(description="A JSON object containing Finder information")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[FinderSchema]:
        """Create Finder

        Creates a new finder search in your account.  ### Finder's Attributes  Here is a table that describes the attributes of the finder object:  | Attribute | Type | Required | Description | |-----------|------|----------|-------------| | `name` | string | Yes | The name of the finder search (1-256 characters) | | `type` | string | Yes | The type of search: talents, candidates, jobs, emails, users, reports | | `query` | object | No | The search query parameters sent to OpenSearch (e.g. `{ \"type\": \"talents\", \"jobId\": \"...\" }`) | | `results` | object | No | The search results (auto-populated after OpenSearch query execution) | | `status` | string | No | The current status: active (default), pending, completed, failed, archived | | `languageCode` | string | No | Language code for the finder (default: `en`) | | `settings` | object | No | Additional configuration settings | | `source` | string | No | Source of the finder creation (nullable) | | `ttl` | string | No | Time-to-live expiration timestamp in ISO 8601 format (nullable) | | `timestamps.created` | string | No | The date and time when the finder was created (ISO 8601 format) | | `timestamps.modified` | string | No | The date and time when the finder was last modified (ISO 8601 format) |  ### Relationships  | Relationship | Type | Description | |-------------|------|-------------| | `jobs` | array | Associated job resources | | `users` | array | Associated user resources | | `talents` | array | Associated talent resources | | `candidates` | array | Associated candidate resources |  ### Behavior  When a `query` is provided, OpenSearch is queried immediately. The `results` field is populated with matching documents and `status` is set to `completed` or `failed`.

        :param create_finder_request_body: A JSON object containing Finder information (required)
        :type create_finder_request_body: CreateFinderRequestBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_finder_serialize(
            create_finder_request_body=create_finder_request_body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FinderSchema",
            '400': "ErrorSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def create_finder_without_preload_content(
        self,
        create_finder_request_body: Annotated[CreateFinderRequestBody, Field(description="A JSON object containing Finder information")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create Finder

        Creates a new finder search in your account.  ### Finder's Attributes  Here is a table that describes the attributes of the finder object:  | Attribute | Type | Required | Description | |-----------|------|----------|-------------| | `name` | string | Yes | The name of the finder search (1-256 characters) | | `type` | string | Yes | The type of search: talents, candidates, jobs, emails, users, reports | | `query` | object | No | The search query parameters sent to OpenSearch (e.g. `{ \"type\": \"talents\", \"jobId\": \"...\" }`) | | `results` | object | No | The search results (auto-populated after OpenSearch query execution) | | `status` | string | No | The current status: active (default), pending, completed, failed, archived | | `languageCode` | string | No | Language code for the finder (default: `en`) | | `settings` | object | No | Additional configuration settings | | `source` | string | No | Source of the finder creation (nullable) | | `ttl` | string | No | Time-to-live expiration timestamp in ISO 8601 format (nullable) | | `timestamps.created` | string | No | The date and time when the finder was created (ISO 8601 format) | | `timestamps.modified` | string | No | The date and time when the finder was last modified (ISO 8601 format) |  ### Relationships  | Relationship | Type | Description | |-------------|------|-------------| | `jobs` | array | Associated job resources | | `users` | array | Associated user resources | | `talents` | array | Associated talent resources | | `candidates` | array | Associated candidate resources |  ### Behavior  When a `query` is provided, OpenSearch is queried immediately. The `results` field is populated with matching documents and `status` is set to `completed` or `failed`.

        :param create_finder_request_body: A JSON object containing Finder information (required)
        :type create_finder_request_body: CreateFinderRequestBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_finder_serialize(
            create_finder_request_body=create_finder_request_body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FinderSchema",
            '400': "ErrorSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _create_finder_serialize(
        self,
        create_finder_request_body,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if create_finder_request_body is not None:
            _body_params = create_finder_request_body


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth', 
            'OAuth2Auth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/v1/finders',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def delete_finder(
        self,
        finder_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Delete Finder

        This endpoint allows you to delete a specific finder from your account. Once deleted, the finder's information will be permanently removed and cannot be recovered.

        :param finder_id: (required)
        :type finder_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_finder_serialize(
            finder_id=finder_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def delete_finder_with_http_info(
        self,
        finder_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Delete Finder

        This endpoint allows you to delete a specific finder from your account. Once deleted, the finder's information will be permanently removed and cannot be recovered.

        :param finder_id: (required)
        :type finder_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_finder_serialize(
            finder_id=finder_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def delete_finder_without_preload_content(
        self,
        finder_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Delete Finder

        This endpoint allows you to delete a specific finder from your account. Once deleted, the finder's information will be permanently removed and cannot be recovered.

        :param finder_id: (required)
        :type finder_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_finder_serialize(
            finder_id=finder_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _delete_finder_serialize(
        self,
        finder_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if finder_id is not None:
            _path_params['finderId'] = finder_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth', 
            'OAuth2Auth'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/v1/finders/{finderId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def finder_options(
        self,
        finder_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Finder Options

        Enable CORS by returning correct headers

        :param finder_id: (required)
        :type finder_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._finder_options_serialize(
            finder_id=finder_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def finder_options_with_http_info(
        self,
        finder_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Finder Options

        Enable CORS by returning correct headers

        :param finder_id: (required)
        :type finder_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._finder_options_serialize(
            finder_id=finder_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def finder_options_without_preload_content(
        self,
        finder_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Finder Options

        Enable CORS by returning correct headers

        :param finder_id: (required)
        :type finder_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._finder_options_serialize(
            finder_id=finder_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _finder_options_serialize(
        self,
        finder_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if finder_id is not None:
            _path_params['finderId'] = finder_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='OPTIONS',
            resource_path='/v1/finders/{finderId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def finders_options(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Finders Options

        Enable CORS by returning correct headers

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._finders_options_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def finders_options_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Finders Options

        Enable CORS by returning correct headers

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._finders_options_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def finders_options_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Finders Options

        Enable CORS by returning correct headers

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._finders_options_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _finders_options_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='OPTIONS',
            resource_path='/v1/finders',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def list_finders(
        self,
        filter_status: Annotated[Optional[StrictStr], Field(description="Returns finders with the current status (active, pending, completed, failed, archived). If not provided, the default value will be set to 'active'.")] = None,
        filter_type: Annotated[Optional[StrictStr], Field(description="Returns finders with the specified type (talents, candidates, jobs, emails, users, reports).")] = None,
        filter_created_from: Annotated[Optional[datetime], Field(description="Filters results to include only those created from the specified date and time. The value must be in ISO 8601 format.")] = None,
        filter_created_to: Annotated[Optional[datetime], Field(description="Filters results to include only those created up to the specified date and time. The value must be in ISO 8601 format.")] = None,
        filter_modified_from: Annotated[Optional[datetime], Field(description="Filters results to include only those modified from the specified date and time. The value must be in ISO 8601 format.")] = None,
        filter_modified_to: Annotated[Optional[datetime], Field(description="Filters results to include only those modified up to the specified date and time. The value must be in ISO 8601 format.")] = None,
        page_size: Annotated[Optional[Annotated[int, Field(le=100, strict=True, ge=1)]], Field(description="Specifies the number of items to retrieve per page. The maximum value is 100.")] = None,
        page_number: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="Specifies the page number to retrieve. Used for traditional pagination.")] = None,
        page_after: Annotated[Optional[Any], Field(description="Returns the data encoded in Base64 format, used for cursor-based pagination")] = None,
        page_before: Annotated[Optional[StrictStr], Field(description="Returns the data encoded in Base64 format, used for cursor-based pagination")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> FindersSchema:
        """List Finders

        Returns a collection of your account finders  ## Overview  Returns a collection of your account finders, sorted by the time they were inserted into the system in ascending order.  ### Finders Endpoints Pagination  The finders endpoints support two versions of pagination: traditional and cursor-based. Note that the parameters for these pagination methods cannot coexist; using them together will result in a bad request error.  :::tip Pagination tip  Ensure that when using traditional pagination, you use `pageNumber`, and when using cursor-based pagination, you use either `pageAfter` or `pageBefore`, but not both together.  :::  #### More information For more information, see the [pagination documentation](/docs/pagination).

        :param filter_status: Returns finders with the current status (active, pending, completed, failed, archived). If not provided, the default value will be set to 'active'.
        :type filter_status: str
        :param filter_type: Returns finders with the specified type (talents, candidates, jobs, emails, users, reports).
        :type filter_type: str
        :param filter_created_from: Filters results to include only those created from the specified date and time. The value must be in ISO 8601 format.
        :type filter_created_from: datetime
        :param filter_created_to: Filters results to include only those created up to the specified date and time. The value must be in ISO 8601 format.
        :type filter_created_to: datetime
        :param filter_modified_from: Filters results to include only those modified from the specified date and time. The value must be in ISO 8601 format.
        :type filter_modified_from: datetime
        :param filter_modified_to: Filters results to include only those modified up to the specified date and time. The value must be in ISO 8601 format.
        :type filter_modified_to: datetime
        :param page_size: Specifies the number of items to retrieve per page. The maximum value is 100.
        :type page_size: int
        :param page_number: Specifies the page number to retrieve. Used for traditional pagination.
        :type page_number: int
        :param page_after: Returns the data encoded in Base64 format, used for cursor-based pagination
        :type page_after: object
        :param page_before: Returns the data encoded in Base64 format, used for cursor-based pagination
        :type page_before: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_finders_serialize(
            filter_status=filter_status,
            filter_type=filter_type,
            filter_created_from=filter_created_from,
            filter_created_to=filter_created_to,
            filter_modified_from=filter_modified_from,
            filter_modified_to=filter_modified_to,
            page_size=page_size,
            page_number=page_number,
            page_after=page_after,
            page_before=page_before,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FindersSchema",
            '400': "ErrorSchema",
            '401': "ErrorSchema",
            '404': "ErrorSchema",
            '500': "ErrorSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def list_finders_with_http_info(
        self,
        filter_status: Annotated[Optional[StrictStr], Field(description="Returns finders with the current status (active, pending, completed, failed, archived). If not provided, the default value will be set to 'active'.")] = None,
        filter_type: Annotated[Optional[StrictStr], Field(description="Returns finders with the specified type (talents, candidates, jobs, emails, users, reports).")] = None,
        filter_created_from: Annotated[Optional[datetime], Field(description="Filters results to include only those created from the specified date and time. The value must be in ISO 8601 format.")] = None,
        filter_created_to: Annotated[Optional[datetime], Field(description="Filters results to include only those created up to the specified date and time. The value must be in ISO 8601 format.")] = None,
        filter_modified_from: Annotated[Optional[datetime], Field(description="Filters results to include only those modified from the specified date and time. The value must be in ISO 8601 format.")] = None,
        filter_modified_to: Annotated[Optional[datetime], Field(description="Filters results to include only those modified up to the specified date and time. The value must be in ISO 8601 format.")] = None,
        page_size: Annotated[Optional[Annotated[int, Field(le=100, strict=True, ge=1)]], Field(description="Specifies the number of items to retrieve per page. The maximum value is 100.")] = None,
        page_number: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="Specifies the page number to retrieve. Used for traditional pagination.")] = None,
        page_after: Annotated[Optional[Any], Field(description="Returns the data encoded in Base64 format, used for cursor-based pagination")] = None,
        page_before: Annotated[Optional[StrictStr], Field(description="Returns the data encoded in Base64 format, used for cursor-based pagination")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[FindersSchema]:
        """List Finders

        Returns a collection of your account finders  ## Overview  Returns a collection of your account finders, sorted by the time they were inserted into the system in ascending order.  ### Finders Endpoints Pagination  The finders endpoints support two versions of pagination: traditional and cursor-based. Note that the parameters for these pagination methods cannot coexist; using them together will result in a bad request error.  :::tip Pagination tip  Ensure that when using traditional pagination, you use `pageNumber`, and when using cursor-based pagination, you use either `pageAfter` or `pageBefore`, but not both together.  :::  #### More information For more information, see the [pagination documentation](/docs/pagination).

        :param filter_status: Returns finders with the current status (active, pending, completed, failed, archived). If not provided, the default value will be set to 'active'.
        :type filter_status: str
        :param filter_type: Returns finders with the specified type (talents, candidates, jobs, emails, users, reports).
        :type filter_type: str
        :param filter_created_from: Filters results to include only those created from the specified date and time. The value must be in ISO 8601 format.
        :type filter_created_from: datetime
        :param filter_created_to: Filters results to include only those created up to the specified date and time. The value must be in ISO 8601 format.
        :type filter_created_to: datetime
        :param filter_modified_from: Filters results to include only those modified from the specified date and time. The value must be in ISO 8601 format.
        :type filter_modified_from: datetime
        :param filter_modified_to: Filters results to include only those modified up to the specified date and time. The value must be in ISO 8601 format.
        :type filter_modified_to: datetime
        :param page_size: Specifies the number of items to retrieve per page. The maximum value is 100.
        :type page_size: int
        :param page_number: Specifies the page number to retrieve. Used for traditional pagination.
        :type page_number: int
        :param page_after: Returns the data encoded in Base64 format, used for cursor-based pagination
        :type page_after: object
        :param page_before: Returns the data encoded in Base64 format, used for cursor-based pagination
        :type page_before: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_finders_serialize(
            filter_status=filter_status,
            filter_type=filter_type,
            filter_created_from=filter_created_from,
            filter_created_to=filter_created_to,
            filter_modified_from=filter_modified_from,
            filter_modified_to=filter_modified_to,
            page_size=page_size,
            page_number=page_number,
            page_after=page_after,
            page_before=page_before,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FindersSchema",
            '400': "ErrorSchema",
            '401': "ErrorSchema",
            '404': "ErrorSchema",
            '500': "ErrorSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def list_finders_without_preload_content(
        self,
        filter_status: Annotated[Optional[StrictStr], Field(description="Returns finders with the current status (active, pending, completed, failed, archived). If not provided, the default value will be set to 'active'.")] = None,
        filter_type: Annotated[Optional[StrictStr], Field(description="Returns finders with the specified type (talents, candidates, jobs, emails, users, reports).")] = None,
        filter_created_from: Annotated[Optional[datetime], Field(description="Filters results to include only those created from the specified date and time. The value must be in ISO 8601 format.")] = None,
        filter_created_to: Annotated[Optional[datetime], Field(description="Filters results to include only those created up to the specified date and time. The value must be in ISO 8601 format.")] = None,
        filter_modified_from: Annotated[Optional[datetime], Field(description="Filters results to include only those modified from the specified date and time. The value must be in ISO 8601 format.")] = None,
        filter_modified_to: Annotated[Optional[datetime], Field(description="Filters results to include only those modified up to the specified date and time. The value must be in ISO 8601 format.")] = None,
        page_size: Annotated[Optional[Annotated[int, Field(le=100, strict=True, ge=1)]], Field(description="Specifies the number of items to retrieve per page. The maximum value is 100.")] = None,
        page_number: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="Specifies the page number to retrieve. Used for traditional pagination.")] = None,
        page_after: Annotated[Optional[Any], Field(description="Returns the data encoded in Base64 format, used for cursor-based pagination")] = None,
        page_before: Annotated[Optional[StrictStr], Field(description="Returns the data encoded in Base64 format, used for cursor-based pagination")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List Finders

        Returns a collection of your account finders  ## Overview  Returns a collection of your account finders, sorted by the time they were inserted into the system in ascending order.  ### Finders Endpoints Pagination  The finders endpoints support two versions of pagination: traditional and cursor-based. Note that the parameters for these pagination methods cannot coexist; using them together will result in a bad request error.  :::tip Pagination tip  Ensure that when using traditional pagination, you use `pageNumber`, and when using cursor-based pagination, you use either `pageAfter` or `pageBefore`, but not both together.  :::  #### More information For more information, see the [pagination documentation](/docs/pagination).

        :param filter_status: Returns finders with the current status (active, pending, completed, failed, archived). If not provided, the default value will be set to 'active'.
        :type filter_status: str
        :param filter_type: Returns finders with the specified type (talents, candidates, jobs, emails, users, reports).
        :type filter_type: str
        :param filter_created_from: Filters results to include only those created from the specified date and time. The value must be in ISO 8601 format.
        :type filter_created_from: datetime
        :param filter_created_to: Filters results to include only those created up to the specified date and time. The value must be in ISO 8601 format.
        :type filter_created_to: datetime
        :param filter_modified_from: Filters results to include only those modified from the specified date and time. The value must be in ISO 8601 format.
        :type filter_modified_from: datetime
        :param filter_modified_to: Filters results to include only those modified up to the specified date and time. The value must be in ISO 8601 format.
        :type filter_modified_to: datetime
        :param page_size: Specifies the number of items to retrieve per page. The maximum value is 100.
        :type page_size: int
        :param page_number: Specifies the page number to retrieve. Used for traditional pagination.
        :type page_number: int
        :param page_after: Returns the data encoded in Base64 format, used for cursor-based pagination
        :type page_after: object
        :param page_before: Returns the data encoded in Base64 format, used for cursor-based pagination
        :type page_before: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_finders_serialize(
            filter_status=filter_status,
            filter_type=filter_type,
            filter_created_from=filter_created_from,
            filter_created_to=filter_created_to,
            filter_modified_from=filter_modified_from,
            filter_modified_to=filter_modified_to,
            page_size=page_size,
            page_number=page_number,
            page_after=page_after,
            page_before=page_before,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FindersSchema",
            '400': "ErrorSchema",
            '401': "ErrorSchema",
            '404': "ErrorSchema",
            '500': "ErrorSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _list_finders_serialize(
        self,
        filter_status,
        filter_type,
        filter_created_from,
        filter_created_to,
        filter_modified_from,
        filter_modified_to,
        page_size,
        page_number,
        page_after,
        page_before,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if filter_status is not None:
            
            _query_params.append(('filterStatus', filter_status))
            
        if filter_type is not None:
            
            _query_params.append(('filterType', filter_type))
            
        if filter_created_from is not None:
            if isinstance(filter_created_from, datetime):
                _query_params.append(
                    (
                        'filterCreatedFrom',
                        filter_created_from.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('filterCreatedFrom', filter_created_from))
            
        if filter_created_to is not None:
            if isinstance(filter_created_to, datetime):
                _query_params.append(
                    (
                        'filterCreatedTo',
                        filter_created_to.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('filterCreatedTo', filter_created_to))
            
        if filter_modified_from is not None:
            if isinstance(filter_modified_from, datetime):
                _query_params.append(
                    (
                        'filterModifiedFrom',
                        filter_modified_from.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('filterModifiedFrom', filter_modified_from))
            
        if filter_modified_to is not None:
            if isinstance(filter_modified_to, datetime):
                _query_params.append(
                    (
                        'filterModifiedTo',
                        filter_modified_to.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('filterModifiedTo', filter_modified_to))
            
        if page_size is not None:
            
            _query_params.append(('pageSize', page_size))
            
        if page_number is not None:
            
            _query_params.append(('pageNumber', page_number))
            
        if page_after is not None:
            
            _query_params.append(('pageAfter', page_after))
            
        if page_before is not None:
            
            _query_params.append(('pageBefore', page_before))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth', 
            'OAuth2Auth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v1/finders',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def show_finder(
        self,
        finder_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> FinderSchema:
        """Show Finder

        This endpoint retrieves details of a specific finder from your account. You can view information such as name, type, query, results, status, settings, and other relevant attributes of the finder.

        :param finder_id: (required)
        :type finder_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._show_finder_serialize(
            finder_id=finder_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FinderSchema",
            '400': "ErrorSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def show_finder_with_http_info(
        self,
        finder_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[FinderSchema]:
        """Show Finder

        This endpoint retrieves details of a specific finder from your account. You can view information such as name, type, query, results, status, settings, and other relevant attributes of the finder.

        :param finder_id: (required)
        :type finder_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._show_finder_serialize(
            finder_id=finder_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FinderSchema",
            '400': "ErrorSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def show_finder_without_preload_content(
        self,
        finder_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Show Finder

        This endpoint retrieves details of a specific finder from your account. You can view information such as name, type, query, results, status, settings, and other relevant attributes of the finder.

        :param finder_id: (required)
        :type finder_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._show_finder_serialize(
            finder_id=finder_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FinderSchema",
            '400': "ErrorSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _show_finder_serialize(
        self,
        finder_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if finder_id is not None:
            _path_params['finderId'] = finder_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth', 
            'OAuth2Auth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v1/finders/{finderId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def update_finder(
        self,
        finder_id: StrictStr,
        update_finder_request_body: Annotated[UpdateFinderRequestBody, Field(description="A JSON object containing Finder information")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> FinderSchema:
        """Update Finder

        This endpoint allows you to update details of a specific finder in your account. You can modify information such as name, query, status, settings, and other relevant attributes of the finder. Only the fields provided in the request will be updated.

        :param finder_id: (required)
        :type finder_id: str
        :param update_finder_request_body: A JSON object containing Finder information (required)
        :type update_finder_request_body: UpdateFinderRequestBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_finder_serialize(
            finder_id=finder_id,
            update_finder_request_body=update_finder_request_body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FinderSchema",
            '400': "ErrorSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def update_finder_with_http_info(
        self,
        finder_id: StrictStr,
        update_finder_request_body: Annotated[UpdateFinderRequestBody, Field(description="A JSON object containing Finder information")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[FinderSchema]:
        """Update Finder

        This endpoint allows you to update details of a specific finder in your account. You can modify information such as name, query, status, settings, and other relevant attributes of the finder. Only the fields provided in the request will be updated.

        :param finder_id: (required)
        :type finder_id: str
        :param update_finder_request_body: A JSON object containing Finder information (required)
        :type update_finder_request_body: UpdateFinderRequestBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_finder_serialize(
            finder_id=finder_id,
            update_finder_request_body=update_finder_request_body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FinderSchema",
            '400': "ErrorSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def update_finder_without_preload_content(
        self,
        finder_id: StrictStr,
        update_finder_request_body: Annotated[UpdateFinderRequestBody, Field(description="A JSON object containing Finder information")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Update Finder

        This endpoint allows you to update details of a specific finder in your account. You can modify information such as name, query, status, settings, and other relevant attributes of the finder. Only the fields provided in the request will be updated.

        :param finder_id: (required)
        :type finder_id: str
        :param update_finder_request_body: A JSON object containing Finder information (required)
        :type update_finder_request_body: UpdateFinderRequestBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_finder_serialize(
            finder_id=finder_id,
            update_finder_request_body=update_finder_request_body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FinderSchema",
            '400': "ErrorSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _update_finder_serialize(
        self,
        finder_id,
        update_finder_request_body,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if finder_id is not None:
            _path_params['finderId'] = finder_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if update_finder_request_body is not None:
            _body_params = update_finder_request_body


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth', 
            'OAuth2Auth'
        ]

        return self.api_client.param_serialize(
            method='PATCH',
            resource_path='/v1/finders/{finderId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.create_finder_request_body_data import CreateFinderRequestBodyData

class TestCreateFinderRequestBodyData(unittest.TestCase):
    """CreateFinderRequestBodyData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateFinderRequestBodyData:
        """Test CreateFinderRequestBodyData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateFinderRequestBodyData`
        """
        model = CreateFinderRequestBodyData()
        if include_optional:
            return CreateFinderRequestBodyData(
                type = 'finders',
                attributes = smartytalent_client.models.finder_attributes_schema.FinderAttributesSchema(
                    name = '', 
                    type = 'talents', 
                    query = smartytalent_client.models.query.query(), 
                    results = smartytalent_client.models.results.results(), 
                    status = 'active', 
                    language_code = '', 
                    settings = smartytalent_client.models.settings.settings(), 
                    source = '', 
                    short_code = '', 
                    ttl = '', 
                    timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ),
                relationships = smartytalent_client.models.finder_relationships_schema.FinderRelationshipsSchema(
                    jobs = smartytalent_client.models.finder_relationships_jobs_schema.FinderRelationshipsJobsSchema(
                        data = [
                            smartytalent_client.models.finder_relationships_jobs_data_schema.FinderRelationshipsJobsDataSchema(
                                type = 'jobs', 
                                id = '655cde5c9931802df628f3d2de8ca681-2', )
                            ], ), 
                    users = smartytalent_client.models.finder_relationships_users_schema.FinderRelationshipsUsersSchema(), 
                    talents = smartytalent_client.models.finder_relationships_talents_schema.FinderRelationshipsTalentsSchema(), 
                    candidates = smartytalent_client.models.finder_relationships_candidates_schema.FinderRelationshipsCandidatesSchema(), )
            )
        else:
            return CreateFinderRequestBodyData(
                type = 'finders',
                attributes = smartytalent_client.models.finder_attributes_schema.FinderAttributesSchema(
                    name = '', 
                    type = 'talents', 
                    query = smartytalent_client.models.query.query(), 
                    results = smartytalent_client.models.results.results(), 
                    status = 'active', 
                    language_code = '', 
                    settings = smartytalent_client.models.settings.settings(), 
                    source = '', 
                    short_code = '', 
                    ttl = '', 
                    timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ),
        )
        """

    def testCreateFinderRequestBodyData(self):
        """Test CreateFinderRequestBodyData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.timeline_resource_schema import TimelineResourceSchema

class TestTimelineResourceSchema(unittest.TestCase):
    """TimelineResourceSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TimelineResourceSchema:
        """Test TimelineResourceSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TimelineResourceSchema`
        """
        model = TimelineResourceSchema()
        if include_optional:
            return TimelineResourceSchema(
                type = 'timelines',
                id = 'bf325375e030fccba00917317c574773-5',
                attributes = smartytalent_client.models.timeline_attributes_schema.TimelineAttributesSchema(
                    entity_type = 'jobs', 
                    entity_id = '', 
                    action = 'INSERT', 
                    user_id = '', 
                    changes = {
                        'key' : smartytalent_client.models.timeline_attributes_schema_changes_value.TimelineAttributesSchema_changes_value(
                            old = null, 
                            new = null, )
                        }, 
                    summary = {
                        'key' : smartytalent_client.models.timeline_attributes_schema_summary_value.TimelineAttributesSchema_summary_value(
                            title = '', 
                            details = '', 
                            user = smartytalent_client.models.timeline_attributes_schema_summary_value_user.TimelineAttributesSchema_summary_value_user(
                                name = '', 
                                avatar_url = '', ), )
                        }, 
                    timestamps = smartytalent_client.models.timeline_attributes_schema_timestamps.TimelineAttributesSchema_timestamps(
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ),
                relationships = smartytalent_client.models.relationships.relationships(),
                links = smartytalent_client.models.resource_links_schema.ResourceLinksSchema(
                    self = '', ),
                meta = {
                    'key' : ''
                    }
            )
        else:
            return TimelineResourceSchema(
                type = 'timelines',
                id = 'bf325375e030fccba00917317c574773-5',
                attributes = smartytalent_client.models.timeline_attributes_schema.TimelineAttributesSchema(
                    entity_type = 'jobs', 
                    entity_id = '', 
                    action = 'INSERT', 
                    user_id = '', 
                    changes = {
                        'key' : smartytalent_client.models.timeline_attributes_schema_changes_value.TimelineAttributesSchema_changes_value(
                            old = null, 
                            new = null, )
                        }, 
                    summary = {
                        'key' : smartytalent_client.models.timeline_attributes_schema_summary_value.TimelineAttributesSchema_summary_value(
                            title = '', 
                            details = '', 
                            user = smartytalent_client.models.timeline_attributes_schema_summary_value_user.TimelineAttributesSchema_summary_value_user(
                                name = '', 
                                avatar_url = '', ), )
                        }, 
                    timestamps = smartytalent_client.models.timeline_attributes_schema_timestamps.TimelineAttributesSchema_timestamps(
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ),
        )
        """

    def testTimelineResourceSchema(self):
        """Test TimelineResourceSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.talents_api import TalentsApi


class TestTalentsApi(unittest.TestCase):
    """TalentsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TalentsApi()

    def tearDown(self) -> None:
        pass

    def test_create_talent(self) -> None:
        """Test case for create_talent

        Create Talent
        """
        pass

    def test_delete_talent(self) -> None:
        """Test case for delete_talent

        Delete Talent
        """
        pass

    def test_list_talent_candidates(self) -> None:
        """Test case for list_talent_candidates

        List Talent Candidates
        """
        pass

    def test_list_talent_candidates_relationship(self) -> None:
        """Test case for list_talent_candidates_relationship

        List Talent Candidates Relationship
        """
        pass

    def test_list_talents(self) -> None:
        """Test case for list_talents

        List Talents
        """
        pass

    def test_show_talent(self) -> None:
        """Test case for show_talent

        Show Talent
        """
        pass

    def test_talent_candidates_options(self) -> None:
        """Test case for talent_candidates_options

        Talent Candidates Options
        """
        pass

    def test_talent_candidates_relationships_options(self) -> None:
        """Test case for talent_candidates_relationships_options

        Talent Candidates Relationships Options
        """
        pass

    def test_talent_options(self) -> None:
        """Test case for talent_options

        Talent Options
        """
        pass

    def test_talents_options(self) -> None:
        """Test case for talents_options

        Talents Options
        """
        pass

    def test_update_talent(self) -> None:
        """Test case for update_talent

        Update Talent
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.talent_attributes_schema import TalentAttributesSchema

class TestTalentAttributesSchema(unittest.TestCase):
    """TalentAttributesSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TalentAttributesSchema:
        """Test TalentAttributesSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TalentAttributesSchema`
        """
        model = TalentAttributesSchema()
        if include_optional:
            return TalentAttributesSchema(
                status = 'active',
                name = '',
                email = '',
                secondary_email = '',
                timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                    created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                work_email = '',
                phone = '',
                work_phone = '',
                profile_picture_url = '',
                availability = {
                    'key' : smartytalent_client.models.talent_availability_received_criteria_schema.TalentAvailabilityReceivedCriteriaSchema(
                        name = '', 
                        description = '', 
                        priority = 'low', 
                        priority_confidence = 'low', 
                        priority_reasoning = '', 
                        received = [
                            None
                            ], )
                    },
                desired_contract_length = smartytalent_client.models.talent_attributes_desired_contract_length_schema.TalentAttributesDesiredContractLengthSchema(
                    duration = '', 
                    is_assumed = True, 
                    confidence = 'Low', 
                    flexibility = '', 
                    reasoning = '', ),
                employment_type = smartytalent_client.models.talent_attributes_employment_type_schema.TalentAttributesEmploymentTypeSchema(
                    status = '', 
                    is_assumed = True, 
                    confidence = 'Low', 
                    additional_context = '', 
                    reasoning = '', ),
                experience_and_seniority = {
                    'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                        name = '', 
                        description = '', 
                        received = [
                            None
                            ], )
                    },
                break_reason = '',
                quick_insights = {
                    'key' : ''
                    },
                languages_spoken = {
                    'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                        name = '', 
                        description = '', 
                        received = [
                            None
                            ], )
                    },
                social_links = [
                    smartytalent_client.models.talent_attributes_social_link_schema.TalentAttributesSocialLinkSchema(
                        platform = '', 
                        url = '', )
                    ],
                desired_employment_type = [
                    smartytalent_client.models.talent_attributes_desired_employment_type_schema.TalentAttributesDesiredEmploymentTypeSchema(
                        type = '', 
                        is_assumed = True, 
                        confidence = 'Low', 
                        reasoning = '', )
                    ],
                desired_role = [
                    smartytalent_client.models.talent_attributes_desired_role_schema.TalentAttributesDesiredRoleSchema(
                        role = '', 
                        level = '', 
                        is_assumed = True, 
                        confidence = 'Low', 
                        reasoning = '', )
                    ],
                work_preferences = {
                    'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                        name = '', 
                        description = '', 
                        received = [
                            None
                            ], )
                    },
                location_preferences = {
                    'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                        name = '', 
                        description = '', 
                        received = [
                            None
                            ], )
                    },
                work_authorization = {
                    'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                        name = '', 
                        description = '', 
                        received = [
                            None
                            ], )
                    },
                skills_and_expertise = {
                    'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                        name = '', 
                        description = '', 
                        received = [
                            None
                            ], )
                    },
                certifications = {
                    'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                        name = '', 
                        description = '', 
                        received = [
                            None
                            ], )
                    },
                licenses = {
                    'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                        name = '', 
                        description = '', 
                        received = [
                            None
                            ], )
                    },
                professional_experience = {
                    'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                        name = '', 
                        description = '', 
                        received = [
                            None
                            ], )
                    },
                industry_experience = {
                    'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                        name = '', 
                        description = '', 
                        received = [
                            None
                            ], )
                    },
                company_type_experience = {
                    'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                        name = '', 
                        description = '', 
                        received = [
                            None
                            ], )
                    },
                job_positions = {
                    'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                        name = '', 
                        description = '', 
                        received = [
                            None
                            ], )
                    },
                job_tendencies = {
                    'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                        name = '', 
                        description = '', 
                        received = [
                            None
                            ], )
                    },
                education = {
                    'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                        name = '', 
                        description = '', 
                        received = [
                            None
                            ], )
                    },
                projects_and_achievements = {
                    'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                        name = '', 
                        description = '', 
                        received = [
                            None
                            ], )
                    },
                personality_and_soft_skills = {
                    'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                        name = '', 
                        description = '', 
                        received = [
                            None
                            ], )
                    },
                hobbies_and_interests = {
                    'key' : [
                        ''
                        ]
                    },
                references = {
                    'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                        name = '', 
                        description = '', 
                        received = [
                            None
                            ], )
                    },
                keywords = {
                    'key' : [
                        ''
                        ]
                    },
                performance_reviews = [
                    None
                    ],
                personality_tests = { },
                salary_expectation = {
                    'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                        name = '', 
                        description = '', 
                        received = [
                            None
                            ], )
                    },
                relocation_willingness = True,
                requires_sponsorship = True,
                career_break = True,
                is_talent_pool = True,
                ttl = '',
                alumni = smartytalent_client.models.talent_alumni_schema.TalentAlumniSchema(
                    is_former_employee = True, 
                    previous_tenure_months = 1.337, 
                    wants_to_return = True, ),
                referral = smartytalent_client.models.talent_referral_schema.TalentReferralSchema(
                    is_referred = True, 
                    referral_code = '', 
                    referrer = smartytalent_client.models.talent_referral_schema_referrer.TalentReferralSchema_referrer(
                        email = '', 
                        full_name = '', ), ),
                age = '',
                gender = '',
                settings = { },
                short_code = '',
                source = ''
            )
        else:
            return TalentAttributesSchema(
                name = '',
                email = '',
        )
        """

    def testTalentAttributesSchema(self):
        """Test TalentAttributesSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.job_resource_schema import JobResourceSchema

class TestJobResourceSchema(unittest.TestCase):
    """JobResourceSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> JobResourceSchema:
        """Test JobResourceSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `JobResourceSchema`
        """
        model = JobResourceSchema()
        if include_optional:
            return JobResourceSchema(
                type = 'jobs',
                id = 'bf325375e030fccba00917317c574773-5',
                attributes = smartytalent_client.models.job_attributes_schema.JobAttributesSchema(
                    title = {"en-US":"Senior Software Engineer","pl-PL":"Starszy Inżynier Oprogramowania"}, 
                    description = {"en-US":"We are seeking a senior engineer...","pl-PL":"Szukamy starszego inżyniera..."}, 
                    short_code = '', 
                    source = '', 
                    language_code = 'en-US', 
                    status = 'active', 
                    timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                    department = {"en-US":"Engineering","pl-PL":"Inżynieria"}, 
                    specialization = {"en-US":"General Legal Practice","pl-PL":"Ogólna praktyka prawnicza"}, 
                    company_culture = '', 
                    seniority = '', 
                    availability = {
                        'key' : smartytalent_client.models.job_criteria_schema.JobCriteriaSchema(
                            name = '', 
                            description = '', 
                            priority = 'low', 
                            priority_confidence = 'low', 
                            priority_reasoning = '', 
                            comparison_rule = '', 
                            expected = [
                                None
                                ], )
                        }, 
                    responsibilities = {"en-US":["Lead and mentor a team","Drive development of solutions"],"pl-PL":["Kierowanie i mentorowanie zespołu","Napędzanie rozwoju rozwiązań"]}, 
                    skills_and_expertise = {
                        'key' : smartytalent_client.models.job_criteria_schema.JobCriteriaSchema(
                            name = '', 
                            description = '', 
                            priority = 'low', 
                            priority_confidence = 'low', 
                            priority_reasoning = '', 
                            comparison_rule = '', )
                        }, 
                    languages_spoken = {
                        'key' : 
                        }, 
                    work_preferences = {
                        'key' : 
                        }, 
                    location_preferences = {
                        'key' : 
                        }, 
                    industry_experience = {
                        'key' : 
                        }, 
                    company_type_experience = {
                        'key' : 
                        }, 
                    job_positions = {
                        'key' : 
                        }, 
                    job_tendencies = {
                        'key' : 
                        }, 
                    keywords = {"en-US":["Python","React","AWS"],"pl-PL":["Python","React","AWS"]}, 
                    work_authorization = {
                        'key' : 
                        }, 
                    certifications = {
                        'key' : 
                        }, 
                    licenses = {
                        'key' : 
                        }, 
                    personality_and_soft_skills = {
                        'key' : 
                        }, 
                    education = {
                        'key' : 
                        }, 
                    experience_and_seniority = {
                        'key' : 
                        }, 
                    benefits = {"en-US":["Private health insurance","Flexible work options"],"pl-PL":["Prywatne ubezpieczenie zdrowotne","Elastyczne opcje pracy"]}, 
                    salary_expectation = {
                        'key' : 
                        }, 
                    locations = {"en-US":[{"city":"Warsaw","country":"Poland","region":"Masovian"}],"pl-PL":[{"city":"Warszawa","country":"Polska","region":"Mazowieckie"}]}, 
                    sites = {"en-US":[{"siteType":"office"},{"siteType":"hybrid"}],"pl-PL":[{"siteType":"biuro"},{"siteType":"hybrydowy"}]}, 
                    organization = smartytalent_client.models.job_attributes_organization_schema.JobAttributesOrganizationSchema(
                        name = '', 
                        address = smartytalent_client.models.job_attributes_organization_address_schema.JobAttributesOrganizationAddressSchema(
                            city = '', 
                            country = '', 
                            county = '', 
                            postalcode = '', 
                            street = '', ), ), 
                    settings = smartytalent_client.models.job_attributes_settings_schema.JobAttributesSettingsSchema(
                        conversation = smartytalent_client.models.job_attributes_settings_conversation_schema.JobAttributesSettingsConversationSchema(
                            email = smartytalent_client.models.job_attributes_settings_conversation_email_schema.JobAttributesSettingsConversationEmailSchema(
                                contact = smartytalent_client.models.job_attributes_settings_conversation_email_contact_schema.JobAttributesSettingsConversationEmailContactSchema(
                                    cc = [
                                        ''
                                        ], 
                                    bcc = [
                                        ''
                                        ], ), 
                                delays = smartytalent_client.models.job_attributes_settings_conversation_email_delays_schema.JobAttributesSettingsConversationEmailDelaysSchema(
                                    initial = '', ), 
                                external_sender = True, 
                                is_sendable = True, ), 
                            candidate_interview = smartytalent_client.models.job_attributes_settings_conversation_candidate_interview_schema.JobAttributesSettingsConversationCandidateInterviewSchema(
                                enabled = True, 
                                questions = True, ), 
                            persona_interview = smartytalent_client.models.job_attributes_settings_conversation_persona_interview_schema.JobAttributesSettingsConversationPersonaInterviewSchema(
                                enabled = True, ), 
                            tone = '', ), 
                        criterias = smartytalent_client.models.job_attributes_settings_criterias_schema.JobAttributesSettingsCriteriasSchema(
                            weight = '', 
                            mandatory_criteria_rejection_rating = '', 
                            mandatory_criteria_satisfy_rating = '', ), 
                        operation = smartytalent_client.models.job_attributes_settings_operation_schema.JobAttributesSettingsOperationSchema(
                            change_stage = True, 
                            create_conversation_report = True, 
                            create_note = True, 
                            create_rate = True, 
                            create_tag = True, ), 
                        persona = smartytalent_client.models.job_attributes_settings_persona_schema.JobAttributesSettingsPersonaSchema(
                            weight = '', ), 
                        rating_restrictiveness = '', ), ),
                relationships = smartytalent_client.models.job_relationships_schema.JobRelationshipsSchema(
                    candidates = smartytalent_client.models.job_relationships_candidates_schema.JobRelationshipsCandidatesSchema(
                        data = [
                            smartytalent_client.models.job_relationships_candidates_data_schema.JobRelationshipsCandidatesDataSchema(
                                type = 'candidates', 
                                id = '655cde5c9931802df628f3d2de8ca681-2', )
                            ], ), 
                    translations = smartytalent_client.models.job_relationships_translations_schema.JobRelationshipsTranslationsSchema(), 
                    operations = smartytalent_client.models.job_relationships_operations_schema.JobRelationshipsOperationsSchema(), 
                    conversations = smartytalent_client.models.job_relationships_conversations_schema.JobRelationshipsConversationsSchema(), 
                    personas = smartytalent_client.models.job_relationships_personas_schema.JobRelationshipsPersonasSchema(), ),
                links = smartytalent_client.models.resource_links_schema.ResourceLinksSchema(
                    self = '', ),
                meta = {
                    'key' : ''
                    }
            )
        else:
            return JobResourceSchema(
                type = 'jobs',
                id = 'bf325375e030fccba00917317c574773-5',
                attributes = smartytalent_client.models.job_attributes_schema.JobAttributesSchema(
                    title = {"en-US":"Senior Software Engineer","pl-PL":"Starszy Inżynier Oprogramowania"}, 
                    description = {"en-US":"We are seeking a senior engineer...","pl-PL":"Szukamy starszego inżyniera..."}, 
                    short_code = '', 
                    source = '', 
                    language_code = 'en-US', 
                    status = 'active', 
                    timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                    department = {"en-US":"Engineering","pl-PL":"Inżynieria"}, 
                    specialization = {"en-US":"General Legal Practice","pl-PL":"Ogólna praktyka prawnicza"}, 
                    company_culture = '', 
                    seniority = '', 
                    availability = {
                        'key' : smartytalent_client.models.job_criteria_schema.JobCriteriaSchema(
                            name = '', 
                            description = '', 
                            priority = 'low', 
                            priority_confidence = 'low', 
                            priority_reasoning = '', 
                            comparison_rule = '', 
                            expected = [
                                None
                                ], )
                        }, 
                    responsibilities = {"en-US":["Lead and mentor a team","Drive development of solutions"],"pl-PL":["Kierowanie i mentorowanie zespołu","Napędzanie rozwoju rozwiązań"]}, 
                    skills_and_expertise = {
                        'key' : smartytalent_client.models.job_criteria_schema.JobCriteriaSchema(
                            name = '', 
                            description = '', 
                            priority = 'low', 
                            priority_confidence = 'low', 
                            priority_reasoning = '', 
                            comparison_rule = '', )
                        }, 
                    languages_spoken = {
                        'key' : 
                        }, 
                    work_preferences = {
                        'key' : 
                        }, 
                    location_preferences = {
                        'key' : 
                        }, 
                    industry_experience = {
                        'key' : 
                        }, 
                    company_type_experience = {
                        'key' : 
                        }, 
                    job_positions = {
                        'key' : 
                        }, 
                    job_tendencies = {
                        'key' : 
                        }, 
                    keywords = {"en-US":["Python","React","AWS"],"pl-PL":["Python","React","AWS"]}, 
                    work_authorization = {
                        'key' : 
                        }, 
                    certifications = {
                        'key' : 
                        }, 
                    licenses = {
                        'key' : 
                        }, 
                    personality_and_soft_skills = {
                        'key' : 
                        }, 
                    education = {
                        'key' : 
                        }, 
                    experience_and_seniority = {
                        'key' : 
                        }, 
                    benefits = {"en-US":["Private health insurance","Flexible work options"],"pl-PL":["Prywatne ubezpieczenie zdrowotne","Elastyczne opcje pracy"]}, 
                    salary_expectation = {
                        'key' : 
                        }, 
                    locations = {"en-US":[{"city":"Warsaw","country":"Poland","region":"Masovian"}],"pl-PL":[{"city":"Warszawa","country":"Polska","region":"Mazowieckie"}]}, 
                    sites = {"en-US":[{"siteType":"office"},{"siteType":"hybrid"}],"pl-PL":[{"siteType":"biuro"},{"siteType":"hybrydowy"}]}, 
                    organization = smartytalent_client.models.job_attributes_organization_schema.JobAttributesOrganizationSchema(
                        name = '', 
                        address = smartytalent_client.models.job_attributes_organization_address_schema.JobAttributesOrganizationAddressSchema(
                            city = '', 
                            country = '', 
                            county = '', 
                            postalcode = '', 
                            street = '', ), ), 
                    settings = smartytalent_client.models.job_attributes_settings_schema.JobAttributesSettingsSchema(
                        conversation = smartytalent_client.models.job_attributes_settings_conversation_schema.JobAttributesSettingsConversationSchema(
                            email = smartytalent_client.models.job_attributes_settings_conversation_email_schema.JobAttributesSettingsConversationEmailSchema(
                                contact = smartytalent_client.models.job_attributes_settings_conversation_email_contact_schema.JobAttributesSettingsConversationEmailContactSchema(
                                    cc = [
                                        ''
                                        ], 
                                    bcc = [
                                        ''
                                        ], ), 
                                delays = smartytalent_client.models.job_attributes_settings_conversation_email_delays_schema.JobAttributesSettingsConversationEmailDelaysSchema(
                                    initial = '', ), 
                                external_sender = True, 
                                is_sendable = True, ), 
                            candidate_interview = smartytalent_client.models.job_attributes_settings_conversation_candidate_interview_schema.JobAttributesSettingsConversationCandidateInterviewSchema(
                                enabled = True, 
                                questions = True, ), 
                            persona_interview = smartytalent_client.models.job_attributes_settings_conversation_persona_interview_schema.JobAttributesSettingsConversationPersonaInterviewSchema(
                                enabled = True, ), 
                            tone = '', ), 
                        criterias = smartytalent_client.models.job_attributes_settings_criterias_schema.JobAttributesSettingsCriteriasSchema(
                            weight = '', 
                            mandatory_criteria_rejection_rating = '', 
                            mandatory_criteria_satisfy_rating = '', ), 
                        operation = smartytalent_client.models.job_attributes_settings_operation_schema.JobAttributesSettingsOperationSchema(
                            change_stage = True, 
                            create_conversation_report = True, 
                            create_note = True, 
                            create_rate = True, 
                            create_tag = True, ), 
                        persona = smartytalent_client.models.job_attributes_settings_persona_schema.JobAttributesSettingsPersonaSchema(
                            weight = '', ), 
                        rating_restrictiveness = '', ), ),
        )
        """

    def testJobResourceSchema(self):
        """Test JobResourceSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.candidate_resource_schema import CandidateResourceSchema

class TestCandidateResourceSchema(unittest.TestCase):
    """CandidateResourceSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CandidateResourceSchema:
        """Test CandidateResourceSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CandidateResourceSchema`
        """
        model = CandidateResourceSchema()
        if include_optional:
            return CandidateResourceSchema(
                type = 'candidates',
                id = 'bf325375e030fccba00917317c574773-5',
                attributes = smartytalent_client.models.candidate_attributes_schema.CandidateAttributesSchema(
                    name = '', 
                    email = '', 
                    secondary_email = '', 
                    work_email = '', 
                    phone = '', 
                    work_phone = '', 
                    status = 'active', 
                    stage = 'sourced', 
                    age = '', 
                    gender = '', 
                    source = '', 
                    short_code = '', 
                    language_code = '', 
                    recommendation_status_code = 56, 
                    overall_match_rating = 56, 
                    prev_overall_match_rating = 56, 
                    ttl = '', 
                    timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                    alumni = smartytalent_client.models.talent_alumni_schema.TalentAlumniSchema(
                        is_former_employee = True, 
                        previous_tenure_months = 1.337, 
                        wants_to_return = True, ), 
                    referral = smartytalent_client.models.talent_referral_schema.TalentReferralSchema(
                        is_referred = True, 
                        referral_code = '', 
                        referrer = smartytalent_client.models.talent_referral_schema_referrer.TalentReferralSchema_referrer(
                            email = '', 
                            full_name = '', ), ), 
                    job_position_title = {
                        'key' : ''
                        }, 
                    rejection_ticket = {
                        'key' : ''
                        }, 
                    recommendation_status = {
                        'key' : None
                        }, 
                    overall_assessment = {
                        'key' : None
                        }, 
                    next_steps = {
                        'key' : None
                        }, 
                    insights_and_analysis = {
                        'key' : None
                        }, 
                    keywords = {
                        'key' : None
                        }, 
                    availability = {
                        'key' : smartytalent_client.models.candidate_criteria_schema.CandidateCriteriaSchema(
                            name = '', 
                            description = '', 
                            priority = 'low', 
                            priority_confidence = 'low', 
                            priority_reasoning = '', 
                            expected = [
                                None
                                ], 
                            received = [
                                None
                                ], 
                            weight = '', 
                            rating = 1.337, 
                            prev_rating = 1.337, 
                            data_available = True, 
                            comparison_confidence = '', 
                            comparison_reasoning = '', 
                            is_comparison_assumed = True, )
                        }, 
                    certifications = {
                        'key' : smartytalent_client.models.candidate_criteria_schema.CandidateCriteriaSchema(
                            name = '', 
                            description = '', 
                            priority = 'low', 
                            priority_confidence = 'low', 
                            priority_reasoning = '', 
                            weight = '', 
                            rating = 1.337, 
                            prev_rating = 1.337, 
                            data_available = True, 
                            comparison_confidence = '', 
                            comparison_reasoning = '', 
                            is_comparison_assumed = True, )
                        }, 
                    company_type_experience = {
                        'key' : 
                        }, 
                    education = {
                        'key' : 
                        }, 
                    experience_and_seniority = {
                        'key' : 
                        }, 
                    industry_experience = {
                        'key' : 
                        }, 
                    job_positions = {
                        'key' : 
                        }, 
                    job_tendencies = {
                        'key' : 
                        }, 
                    languages_spoken = {
                        'key' : 
                        }, 
                    licenses = {
                        'key' : 
                        }, 
                    location_preferences = {
                        'key' : 
                        }, 
                    personality_and_soft_skills = {
                        'key' : 
                        }, 
                    salary_expectation = {
                        'key' : 
                        }, 
                    skills_and_expertise = {
                        'key' : 
                        }, 
                    work_authorization = {
                        'key' : 
                        }, 
                    work_preferences = {
                        'key' : 
                        }, ),
                relationships = smartytalent_client.models.candidate_relationships_schema.CandidateRelationshipsSchema(
                    job = smartytalent_client.models.candidate_relationships_job_schema.CandidateRelationshipsJobSchema(
                        data = smartytalent_client.models.candidate_relationships_job_data_schema.CandidateRelationshipsJobDataSchema(
                            type = 'jobs', 
                            id = '655cde5c9931802df628f3d2de8ca681-2', ), ), 
                    talent = smartytalent_client.models.candidate_relationships_talent_schema.CandidateRelationshipsTalentSchema(), 
                    translations = smartytalent_client.models.candidate_relationships_translations_schema.CandidateRelationshipsTranslationsSchema(), 
                    operations = smartytalent_client.models.candidate_relationships_operations_schema.CandidateRelationshipsOperationsSchema(), ),
                links = smartytalent_client.models.resource_links_schema.ResourceLinksSchema(
                    self = '', ),
                meta = {
                    'key' : ''
                    }
            )
        else:
            return CandidateResourceSchema(
                type = 'candidates',
                id = 'bf325375e030fccba00917317c574773-5',
                attributes = smartytalent_client.models.candidate_attributes_schema.CandidateAttributesSchema(
                    name = '', 
                    email = '', 
                    secondary_email = '', 
                    work_email = '', 
                    phone = '', 
                    work_phone = '', 
                    status = 'active', 
                    stage = 'sourced', 
                    age = '', 
                    gender = '', 
                    source = '', 
                    short_code = '', 
                    language_code = '', 
                    recommendation_status_code = 56, 
                    overall_match_rating = 56, 
                    prev_overall_match_rating = 56, 
                    ttl = '', 
                    timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                    alumni = smartytalent_client.models.talent_alumni_schema.TalentAlumniSchema(
                        is_former_employee = True, 
                        previous_tenure_months = 1.337, 
                        wants_to_return = True, ), 
                    referral = smartytalent_client.models.talent_referral_schema.TalentReferralSchema(
                        is_referred = True, 
                        referral_code = '', 
                        referrer = smartytalent_client.models.talent_referral_schema_referrer.TalentReferralSchema_referrer(
                            email = '', 
                            full_name = '', ), ), 
                    job_position_title = {
                        'key' : ''
                        }, 
                    rejection_ticket = {
                        'key' : ''
                        }, 
                    recommendation_status = {
                        'key' : None
                        }, 
                    overall_assessment = {
                        'key' : None
                        }, 
                    next_steps = {
                        'key' : None
                        }, 
                    insights_and_analysis = {
                        'key' : None
                        }, 
                    keywords = {
                        'key' : None
                        }, 
                    availability = {
                        'key' : smartytalent_client.models.candidate_criteria_schema.CandidateCriteriaSchema(
                            name = '', 
                            description = '', 
                            priority = 'low', 
                            priority_confidence = 'low', 
                            priority_reasoning = '', 
                            expected = [
                                None
                                ], 
                            received = [
                                None
                                ], 
                            weight = '', 
                            rating = 1.337, 
                            prev_rating = 1.337, 
                            data_available = True, 
                            comparison_confidence = '', 
                            comparison_reasoning = '', 
                            is_comparison_assumed = True, )
                        }, 
                    certifications = {
                        'key' : smartytalent_client.models.candidate_criteria_schema.CandidateCriteriaSchema(
                            name = '', 
                            description = '', 
                            priority = 'low', 
                            priority_confidence = 'low', 
                            priority_reasoning = '', 
                            weight = '', 
                            rating = 1.337, 
                            prev_rating = 1.337, 
                            data_available = True, 
                            comparison_confidence = '', 
                            comparison_reasoning = '', 
                            is_comparison_assumed = True, )
                        }, 
                    company_type_experience = {
                        'key' : 
                        }, 
                    education = {
                        'key' : 
                        }, 
                    experience_and_seniority = {
                        'key' : 
                        }, 
                    industry_experience = {
                        'key' : 
                        }, 
                    job_positions = {
                        'key' : 
                        }, 
                    job_tendencies = {
                        'key' : 
                        }, 
                    languages_spoken = {
                        'key' : 
                        }, 
                    licenses = {
                        'key' : 
                        }, 
                    location_preferences = {
                        'key' : 
                        }, 
                    personality_and_soft_skills = {
                        'key' : 
                        }, 
                    salary_expectation = {
                        'key' : 
                        }, 
                    skills_and_expertise = {
                        'key' : 
                        }, 
                    work_authorization = {
                        'key' : 
                        }, 
                    work_preferences = {
                        'key' : 
                        }, ),
        )
        """

    def testCandidateResourceSchema(self):
        """Test CandidateResourceSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
